/**************************************************************************
MODULE:    MCO_LIBCB
CONTAINS:  MicroCANopen Lib Helper Functions
COPYRIGHT: (c) Embedded Systems Academy (EmSA) 2002-2022
           All rights reserved. www.em-sa.com/nxp
DISCLAIM:  Read and understand our disclaimer before using this code!
           www.esacademy.com/disclaim.htm
           This software was written in accordance to the guidelines at
           www.esacademy.com/software/softwarestyleguide.pdf
LICENSE:   THIS IS THE NXP SDK VERSION OF MICROCANOPEN PLUS
           Licensed under a modified BSD License. See LICENSE.INFO
           file in the project root for full license information.
VERSION:   7.15, EmSA 24-NOV-22
           $LastChangedDate: 2022-11-24 14:08:20 +0100 (Thu, 24 Nov 2022) $
           $LastChangedRevision: 5359 $
***************************************************************************/ 

#include "mcop_inc.h"
#include "fsl_gpio.h"

/**************************************************************************
DEFINITIONS
***************************************************************************/
// Ports for LEDs
#define LED_NR_MAX 1


/**************************************************************************
GLOBAL FUNCTIONS
***************************************************************************/ 

/**************************************************************************
DOES:    Call-back function to return the size of the process image
RETURNS: Size of the process image
**************************************************************************/
int LIBCB_GetProcImgSize (void)
{
  return PROCIMG_SIZE;
}


/**************************************************************************
DOES:    Initialize I/O for LEDs.
RETURNS: nothing
**************************************************************************/
void LIBCB_InitLeds (
  void
  )
{
  /* Init output LED GPIO. */
  USER_LED_INIT(LOGIC_LED_ON);

  return;
}


/**************************************************************************
DOES:    This function turns a numbered LED on or off.
RETURNS: nothing
**************************************************************************/
void LIBCB_SwitchLeds (
  uint8_t LED_NR,  // LED number
  uint8_t state    // LED state
  )
{
  if (LED_NR == 0)
  {
    if (state)
      USER_LED_ON();
    else
      USER_LED_OFF();
  }
  return;
}


/**************************************************************************
DOES:    Call-back function to return the size of non-volatile 
         memory for stack use.
RETURNS: Size of the non-volatile memory for stack use
**************************************************************************/
int LIBCB_GetNvolSize (void)
{
  return NVOL_STORE_SIZE;
}


/**************************************************************************
DOES:    Call-back function to return the start/offset of non-volatile 
         memory for stack use.
RETURNS: Start/offset of non-volatile memory for stack use
**************************************************************************/
int LIBCB_GetNvolStart (void)
{
  return NVOL_STORE_START;
}


/**************************************************************************
END-OF-FILE 
***************************************************************************/ 

