/**************************************************************************
MODULE:    MCOINST
CONTAINS:  Compatibility with MCO v8+ driver API include
COPYRIGHT: Embedded Systems Academy, Inc. (EmSA) 2002-2022
           All rights reserved. esacademy.com
DISCLAIM:  Read and understand our disclaimer before using this code!
           www.esacademy.com/disclaim.htm
           This software was written in accordance to the guidelines at
           www.esacademy.com/software/softwarestyleguide.pdf
LICENSE:   This file may be freely distributed.
VERSION:   7.15, EmSA 24-NOV-22
           $LastChangedDate: 2022-11-24 14:08:20 +0100 (Thu, 24 Nov 2022) $
           $LastChangedRevision: 5359 $
***************************************************************************/


#ifndef _MCOINST_H
#define _MCOINST_H

#ifdef __cplusplus
extern "C" {
#endif

#include <string.h>
#include "mcohw.h"
#include "canfifo.h"
#include "mcop_inc.h"


#define NUM_CAN_PORTS  1  // This driver supports 1 CAN port

// On the i.MX RT 10xx several CAN ports are supported, this is the number
// of the CAN port used (1-3)
// The CAN interface/port to use with the stack
#define CAN_PORT_NUM (USE_CAN_PORT)

#if NUM_CAN_PORTS==1
#if CAN_PORT_NUM==1
#define CAN_LIST_INITIALIZER {CAN1}
#elif CAN_PORT_NUM==2
#define CAN_LIST_INITIALIZER {CAN2}
#elif CAN_PORT_NUM==3
#define CAN_LIST_INITIALIZER {CAN3}
#endif
#elif NUM_CAN_PORTS==2
#define CAN_LIST_INITIALIZER {CAN1, CAN2}
#elif NUM_CAN_PORTS==3
#define CAN_LIST_INITIALIZER {CAN1, CAN2, CAN3}
#endif

#define CAN_PORT_INDEX 0 // The number from the list of initializers to use

#define OPT_SINGLE_HANDLE_PARAM void
#define OPT_FIRST_HANDLE_PARAM 
#define OPT_SINGLE_HANDLE_CALL_PARAM 
#define OPT_FIRST_HANDLE_CALL_PARAM 


#define MCO_PROT_LEGACY    0x01u
#define MCO_PROT_FD        0x02u
#define MCO_PROT_COMANAGER 0x10u

#if defined(MGR_MONITOR_ALL_NODES) && (MGR_MONITOR_ALL_NODES==1)
#define USE_CANOPEN_MANAGER 1
#else
#define USE_CANOPEN_MANAGER 0
#endif

#if defined(USE_CANOPEN_FD) && (USE_CANOPEN_FD==1)
#define PROCESS_CO_FD 1
#else
#define PROCESS_CO_FD 0
#endif
#if !defined(USE_CANOPEN_FD) || (defined(USE_CANOPEN_FD) && (USE_CANOPEN_FD==0))
#define PROCESS_CO_LEGACY 1
#else
#define PROCESS_CO_LEGACY 0
#endif

#define MCO_PROT_BIT_SET(mco_handle,testbits)  ( \
  (testbits==MCO_PROT_LEGACY) ? PROCESS_CO_LEGACY : \
  (testbits==MCO_PROT_FD) ? PROCESS_CO_FD : \
  (testbits==MCO_PROT_COMANAGER) ? USE_CANOPEN_MANAGER : \
  0)


#define HW_STATUS_USED  gMCOConfig.HWStatus
#define CONFIG_USED  gMCOConfig

// Empty definition of ´handle´
#define handle (void)0

#endif //  _MCOINST_H
/**************************************************************************
END OF FILE
**************************************************************************/

